%define upstream_name	gmpy2

Summary:	Python interface to GMP (v2)
Name:		python-%{upstream_name}
Version:	2.2.1
Release:	%mkrel 3
License: 	LGPLv3+ and GPLv3+
Group: 		Development/Python
Url: 		https://github.com/aleaxit/gmpy
Source0:	https://github.com/aleaxit/gmpy/archive/refs/tags/v%{version}.tar.gz

BuildRequires:	pyproject-rpm-macros
BuildRequires:	libgmp-devel >= 4.2.4
BuildRequires:	libmpc-devel
BuildRequires:	pkgconfig(mpfr)

# GMP versions before 4.2.4 have a bug that cause gmpy to segfault.
Requires:	libgmp >= 4.2.4

%description
The General Multiprecision PYthon project (GMPY) focuses on
Python-usable modules providing multiprecision arithmetic
functionality to Python programmers. The project mission includes both
C and C++ Python-modules (for speed) and pure Python modules (for
flexibility and convenience); it potentially includes integral,
rational and floating-point arithmetic in any base. Only
cross-platform functionality is of interest, at least for now.

%package -n python3-%{upstream_name}
Summary:	Python 3 interface to GMP
Group:		Development/Python
%{?python_provide:%python_provide python3-%{upstream_name}}
BuildRequires:	pkgconfig(python3)

%description -n python3-%{upstream_name}
The General Multiprecision PYthon project (GMPY) focuses on
Python 3 usable modules providing multiprecision arithmetic
functionality to Python 3 programmers. The project mission includes both
C and C++ Python-modules (for speed) and pure Python 3 modules (for
flexibility and convenience); it potentially includes integral,
rational and floating-point arithmetic in any base. Only
cross-platform functionality is of interest, at least for now.


%prep
%autosetup -p1 -n gmpy-%{version}
# fix linking error, 'log' not found
sed -i "s/gmp'/gmp','m'/" setup.py

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files gmpy2
chmod 755 %{buildroot}%{python3_sitearch}/gmpy2/gmpy2*.so

%check
# Make python see the library that we have just compiled
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir

cd test_cython
%{__python3} runtests.py

%files -n python3-%{upstream_name} -f %{pyproject_files}
%doc README.rst test/
%license COPYING COPYING.LESSER


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 2.2.1-3.mga10
+ Revision: 2238334
- Mageia 10 Mass Rebuild

* Sat Mar 01 2025 wally <wally> 2.2.1-2.mga10
+ Revision: 2155017
- rebuild for python3.13

* Sat Dec 21 2024 papoteur <papoteur> 2.2.1-1.mga10
+ Revision: 2127072
- new version 2.2.1

* Fri Feb 23 2024 daviddavid <daviddavid> 2.1.5-2.mga10
+ Revision: 2043451
- add upstream patch for python 3.12 compatibility
- add patch for MPFR 4.2.1
- rebuild for py3.12

* Mon Sep 11 2023 papoteur <papoteur> 2.1.5-1.mga10
+ Revision: 1986189
- new 2.1.5

* Mon Mar 21 2022 umeabot <umeabot> 2.1.2-2.mga9
+ Revision: 1816646
- Mageia 9 Mass Rebuild

* Sun Mar 13 2022 danf <danf> 2.1.2-1.mga9
+ Revision: 1790808
- Update to ver. 2.1.2
- Change license tag to match license change
- Update source URL

* Tue Apr 20 2021 daviddavid <daviddavid> 2.0.8-7.mga9
+ Revision: 1717340
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 2.0.8-6.mga8
+ Revision: 1535629
- Mageia 8 Mass Rebuild

* Sun Oct 13 2019 tv <tv> 2.0.8-5.mga8
+ Revision: 1452606
- rebuild for python-3.8
- drop python2 subpkg

* Wed Jan 09 2019 shlomif <shlomif> 2.0.8-4.mga7
+ Revision: 1353185
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 2.0.8-3.mga7
+ Revision: 1300487
- Mageia 7 Mass Rebuild

* Mon Feb 26 2018 daviddavid <daviddavid> 2.0.8-2.mga7
+ Revision: 1205303
- rebuild for new mpfr 4.0.1
- rename python-gmpy2 to python2-gmpy2

* Wed Nov 01 2017 shlomif <shlomif> 2.0.8-1.mga7
+ Revision: 1175376
- import based on py-gmpy

